#
# spec file for package python-usb
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-usb
Version:        1.0.2
Release:        3.1
Summary:        USB access on the Python language
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://walac.github.io/pyusb
Source:         https://files.pythonhosted.org/packages/source/p/pyusb/pyusb-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Provides USB access to the Python language.

%prep
%setup -q -n pyusb-%{version}
# Convert dos format files to unix format
find .  -name "*.rst" -exec dos2unix {} +

%build
%python_build

%install
%python_install

%files %{python_files}
%defattr(-,root,root)
%doc ACKNOWLEDGEMENTS ChangeLog LICENSE README.rst docs/*
%{python_sitelib}/*

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Fri Oct 13 2017 arun@gmx.de
- specfile:
  * require setuptools
  * update tar-ball name (lowercase)
  * update url
  * added Changelog to %%doc
- update to version 1.0.2:
  * Add deploy script for automated deployment.
  * Revert "[ADD] pyusb module to satisfy setuptools"
  * [ADD] pyusb module to satisfy setuptools
  * enable building as a wheel by using setuptools
- changes from version 1.0.1:
  * Update version to 1.0.1. After changes in zc.buildout/setuptools
    the tarball name needs to match case sensitive the package name
    defined in setup.py
  * Add message for new maintainer.
  * [docs] Add section in faq for libusb Windows installation.
  * [docs] Fix tutorial link in faq.
  * .gitignore pyusb.egg-info
  * Add topic about configuration selection and handling to FAQ.
  * Update libusb website.
  * Use python syntax highlighting
  * legacy: Fix a few typos in help text
  * legacy: set Bus.location and Device.devnum
  * usb/libloader.py: load_locate_library parameter documentation
  * Remove the quick packaging job, note availability of package in
    Debian
  * Quick Debian packaging
  * Fix setup.py for v1.0.0
  * Typo fix: replace LibaryException with LibraryException.
* Fri Sep  1 2017 jengelh@inai.de
- Remove future plans/visions from description.
* Wed Aug 30 2017 toddrme2178@gmail.com
- singlespec auto-conversion
- Use pypi source URL.
* Wed Sep 28 2016 stefan.bruens@rwth-aachen.de
- update to release version 1.0.0
* Fri Jun  6 2014 arun@gmx.de
- update to version 1.0.0b1
  * Isochronous transfer for libusb 1.0 (by David Halter).
  * Experimental OpenUSB support.
  * Documentation update.
  * PYUSB_DEBUG_LEVEL environment variable is now called PYUSB_DEBUG.
  * Legacy module nwo groups according to their bus.
  * Version information available for apps (by Chris Clark).
  * Faster read operation (by themperek).
  * Tox support (by ponty).
  * Support for port number info (by Stefano Di Martino).
  * Several bug fixes (please, check the Changelog file).
- spec file: removed Changelog from %%files section
- spec file: removed --record-rpm=INSTALLED_FILES
* Tue Jan 22 2013 joop.boonen@opensuse.org
- Build version 1.0.0a3
  + Fixed: find() function returns -1 when not findind a substring.
  + PATH_MAX is 1024 for all *BSD machines.
  + Fixed type in libusb0 backend.
  + Fixed: correct PATH_MAX for Darwin/Mac OSX.
  + Fixed: correct value of PATH_MAX for FreeBSD
  + Renamed libusb01 backend to libusb0.
  + Renamed libusb10 backend to libusb1
    libusb 1.0 and libusbx probably will have backward compatibility across
    all 1.x version, so there is no point in calling the backend libusb10,
    since it should work with all 1.x series of the library.
  + Limit zeroth string descriptor request to 254 bytes
    This string descriptor cannot be longer than 255 bytes anyway, since
    its length is defined by its first byte.
    Also, the libusb code warns "Some devices choke on size > 255".
    Since each language code is two byte long, only an even
    number of bytes makes sense, so request only 254 bytes.
  + Makes legacy byteWrite() and interruptWrite() more compatible with pyusb 0.4.x
    PyUSB 0.4 has a very flexible input buffer treatment. This change does
    not mimic it for all, but make legacy module more close to it.
  + Fix "localtion/location" typo.
  + Limit get_string() length to string descriptor length
    Use the length as reported by the first byte of the descriptor.
    Otherwise (at least for some backend/kernel combinations) the buffer
    length provided by the user would be used instead, and NUL characters
    would be appended to the returned string.
    This also makes the legacy getString() function compatible with
    pyusb 0.4.
  + Return deviceVersion and usbVersion as strings
    PyUSB 0.4 sets deviceVerion and usbVersion attributes as strings. So do
    it for the legacy module.
  + Fixed syntax errors for Python 2.4
  + Merge pull request #4 from JNRowe/master
    Very minor fixes to tutorial
  + Use __ suffix for inline links in reST.
    Very minor, but stops docutils issuing a unreferenced link warning.
  + Fixed alternate_setting in tutorial.
    Typo and missing dev parameter.
  + patch for data loss
  + Fixed configuration indexing in the tutorial
  + Updated ACKNOWLEDGEMENTS file.
  + Fixed: allow Interface objects as parameters for kernel driver functions
  + Fixed: do not used version_info named parameters to preserve backward compatibility
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix building on SLES
* Tue Apr 17 2012 joop.boonen@opensuse.org
- Build version 1.0.0a2
- Included coded fixes
  - MANIFEST.in: Removed old test firmware from manifest file
  - usb/backend/libusb10.py, usb/backend/openusb.py: Fixed: use None
    when errno value is not available
  - tests/utils.py: Fixed Python 3 string test case for ctrl_transfer
    In Python 3, string is 4 bytes long, so ctrl_transfer test case was
    failing with 'Broken error' message. This was caused because control
    buffer in the benchmark firmware can only hold 8 bytes, thus it
    could not handle more than a two character length string.
  - usb/backend/libusb01.py: Fixed correct device enumeration for
    libusb01 backend
* Thu Mar 31 2011 prusnak@opensuse.org
- remove tests from the tarball
  - they are not used during the build and contain firmware files
    with unknown licenses
* Tue Mar 29 2011 prusnak@opensuse.org
- updated to 1.0.0 alpha 1
  - implemented standard control requests
  - finish implementation of 0.4 API emulation
  - documentation update
  - tutorial update
* Mon Dec 20 2010 prusnak@opensuse.org
- created package (1.0.0 alpha 0)
